# サンプルコマンド

## 注意点

* サンプルディレクトリ内でDockerコンテナを実行
* サンプルディレクトリをDockerボリュームでマウントする

```bash
docker run --rm -it -v ./:/code python:3.11.4 bash
cd /code
```

## Pythonのインストール

```bash
# Ubuntu/apt
apt install python3
# AmazonLinux/yum
yum install python3
```

## Docker

```bash
# DockerでPythonコンテナの起動(Pythonインタプリタの起動)
docker run --rm -it library/python:3.11
docker run --rm -it python:3.11
# DockerでPythonコンテナの起動(bashの起動)
docker run --rm -it python:3.11 bash
```

## 仮想環境/venv

```bash
# 仮想環境の作成
python3.11 -m venv venv
# 仮想環境に入る(bash/zsh)
source ./venv/bin/activate
# 仮想環境に入る(fish)
source ./venv/bin/activate.fish
# 仮想環境から出る
deactivate
```

## pip

```bash
# pipでのインストール。今回はboto3をインストールしている
pip install boto3
# 依存ライブラリの書き出し
pip freeze > requirements.txt
# テキストファイルを元にライブラリをインストール
pip install -r requirements.txt
```

## poetry

```bash
# インストール
curl -sSL https://install.python-poetry.org | python3 -
# poetryコマンド実行
~/.local/bin/poetry
# pyproject.tomlの初期化
~/.local/bin/poetry init
# ライブラリの追加
~/.local/bin/poetry add boto3
# pyproject.toml記載のライブラリのインストール
~/.local/bin/poetry install
# lockファイルの更新
~/.local/bin/poetry update
```

## black

```bash
# ライブラリの追加
~/.local/bin/poetry add black
# 実行
black .
```

## ruff

```bash
# ライブラリの追加
~/.local/bin/poetry add ruff
# 実行
ruff .
```

## mypy

```bash
# ライブラリの追加
~/.local/bin/poetry add mypy
# 実行
mypy .
```
